==> paycenter-client-3.4.24-p1-20230705.050717-1-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/wxpay/WxPayLiteChargeRequest.java <==
package cn.com.duiba.paycenter.dto.payment.charge.wxpay;

import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;
import cn.com.duiba.paycenter.validator.MinExpireTime;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.Date;

/**
 * @author zhangruofan
 * @date 2019/01/14
 */
public class WxPayLiteChargeRequest extends BaseChargeRequest {
    private static final long serialVersionUID = 6558221770827762503L;
    /**
     * 终端设备信息
     * 可以不传
     */
    @Size(max = 32, message = "设备信息长度超过32")
    private String deviceInfo;
    /**
     * 订单标题
     * 会传给第三方支付
     */
    @NotNull(message = "支付描述不能为空")
    @Size(max = 128, message = "支付描述长度超过128")
    private String body;
    /**
     * 客户端ip地址
     * 获取用户真实ip
     *
     * @link https://pay.weixin.qq.com/wiki/doc/api/H5_sl.php?chapter=15_5
     */
    @Size(max = 16, message = "ip的长度超过16")
    private String clientIp;
    /**
     * 授权码
     */
//    @NotNull(message = "authCode must not be null")
    @Size(max = 128, message = "授权码超过128")
    private String authCode;

    /**
     * 微信OpenId
     * (和authCode二选一 建议优先适用authCode的方式)
     */
    private String openId;

    /**
     * 交易结束时间
     */
    @MinExpireTime
    private Date timeExpire;

    /**
     * 支付成功回调地址：
     * 不传则走默认
     */
    private String callbackUrl;

    /**
     * 可自定义传递参数 但需要传入json格式字符串 否则解析失败
     */
    private String extJson;


    public String getExtJson() {
        return extJson;
    }

    public void setExtJson(String extJson) {
        this.extJson = extJson;
    }


    public String getCallbackUrl() {
        return callbackUrl;
    }

    public void setCallbackUrl(String callbackUrl) {
        this.callbackUrl = callbackUrl;
    }

    public String getDeviceInfo() {
        return deviceInfo;
    }

    public void setDeviceInfo(String deviceInfo) {
        this.deviceInfo = deviceInfo;
    }

    public String getBody() {
        return body;
    }

    public void setBody(String body) {
        this.body = body;
    }

    public String getClientIp() {
        return clientIp;
    }

    public void setClientIp(String clientIp) {
        this.clientIp = clientIp;
    }

    public String getAuthCode() {
        return authCode;
    }

    public void setAuthCode(String authCode) {
        this.authCode = authCode;
    }

    public Date getTimeExpire() {
        return timeExpire;
    }

    public void setTimeExpire(Date timeExpire) {
        this.timeExpire = timeExpire;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }
}

==> paycenter-client-3.5.33-sources.jar: cn/com/duiba/paycenter/dto/payment/charge/wxpay/WxPayLiteChargeRequest.java <==
package cn.com.duiba.paycenter.dto.payment.charge.wxpay;

import cn.com.duiba.paycenter.dto.payment.charge.BaseChargeRequest;
import cn.com.duiba.paycenter.validator.MinExpireTime;

import javax.validation.constraints.NotNull;
import javax.validation.constraints.Size;
import java.util.Date;

/**
 * @author zhangruofan
 * @date 2019/01/14
 */
public class WxPayLiteChargeRequest extends BaseChargeRequest {
    private static final long serialVersionUID = 6558221770827762503L;
    /**
     * 终端设备信息
     * 可以不传
     */
    @Size(max = 32, message = "设备信息长度超过32")
    private String deviceInfo;
    /**
     * 订单标题
     * 会传给第三方支付
     */
    @NotNull(message = "支付描述不能为空")
    @Size(max = 128, message = "支付描述长度超过128")
    private String body;
    /**
     * 客户端ip地址
     * 获取用户真实ip
     * @link https://pay.weixin.qq.com/wiki/doc/api/H5_sl.php?chapter=15_5
     */
    @Size(max = 16, message = "ip的长度超过16")
    private String clientIp;
    /**
     * 授权码
     */
    @NotNull(message = "authCode must not be null")
    @Size(max = 128, message = "授权码超过128")
    private String authCode;

    /**
     * 交易结束时间
     */
    @MinExpireTime
    private Date timeExpire;

    /**
     * 支付成功回调地址：
     * 不传则走默认
     */
    private String callbackUrl;

    /**
     * 可自定义传递参数 但需要传入json格式字符串 否则解析失败
     */
    private String extJson;

    /**
     * 微信支付所需openId
     */
    private String openId;


    public String getExtJson() {
        return extJson;
    }

    public void setExtJson(String extJson) {
        this.extJson = extJson;
    }

    public String getOpenId() {
        return openId;
    }

    public void setOpenId(String openId) {
        this.openId = openId;
    }

    public String getCallbackUrl() {
        return callbackUrl;
    }

    public void setCallbackUrl(String callbackUrl) {
        this.callbackUrl = callbackUrl;
    }

    public String getDeviceInfo() {
        return deviceInfo;
    }

    public void setDeviceInfo(String deviceInfo) {
        this.deviceInfo = deviceInfo;
    }

    public String getBody() {
        return body;
    }

    public void setBody(String body) {
        this.body = body;
    }

    public String getClientIp() {
        return clientIp;
    }

    public void setClientIp(String clientIp) {
        this.clientIp = clientIp;
    }

    public String getAuthCode() {
        return authCode;
    }

    public void setAuthCode(String authCode) {
        this.authCode = authCode;
    }

    public Date getTimeExpire() {
        return timeExpire;
    }

    public void setTimeExpire(Date timeExpire) {
        this.timeExpire = timeExpire;
    }
}
